    		Originals

    			./sveltnetics_packets/static/Rules_Originals/gpl-3.0-standalone.html.HTML

    		Front Originals

    			./sveltnetics_packets/static/Rules_Front_Originals/Rules.HTML

    		Front Modules

    			./sveltnetics_packets/static/Rules_Front_Modules_Entire/Rules.txt
    			./sveltnetics_packets/static/Rules_Front_Modules_Entire/Rules.txt

    		Python Modules

    			./sveltnetics_packets/static/Rules_Py_Entire/Rules.json
    			./sveltnetics_packets/static/Rules_Py_Legend/Legend.txt

    			"ventures", "somatic", "Emergency", "biotech", "body_scan",
    			"botanist", plus "law_dictionary" licenses or rules can be found
    			at those directories.